
Description of the files
========================

Here a brief descriprion of the main FRETBursts files.


``burstlib.py``
---------------

.. automodule:: fretbursts.burstlib


``loader.py``
--------------

.. automodule:: fretbursts.loader


``select_bursts.py``
--------------------

See :mod:`fretbursts.select_bursts`.


``burst_plot.py``
-----------------

.. automodule:: fretbursts.burst_plot


``background.py``
-----------------

.. automodule:: fretbursts.background


``phtools`` (folder)
---------------------------

.. automodule:: fretbursts.phtools


``dataload`` (folder)
---------------------

.. automodule:: fretbursts.dataload


``fit`` (folder)
----------------

.. automodule:: fretbursts.fit

See :ref:`fit-section`.
